@@ -18,4 +18,7 @@ class UserToken:
     def get_user_id(self):
         return self.token_json['udt']['user_id']
 
+    def get_account_id(self):
+        return self.token_json['udt']['account']['id']
+
 
