@@ -111,22 +111,22 @@ class MyWhatify:
         '''
             set our default store for testing
         '''
-        cls.set_magento_api(magento2url='http://whatify.tempurl.co.il/whatify/api/db/',
-                            magento_header={'Whatify-Merchant-ID': 'j458vgjeDVHe564y3435',
+        cls.set_magento_api(url='http://whatify.tempurl.co.il/whatify/api/db/',
+                            header={'Whatify-Merchant-ID': 'j458vgjeDVHe564y3435',
                                             'Whatify-API-Key': 'n6hcr4_6beuvthg45vw_3v5te5yb565454vbn'})
 
     @classmethod
-    def set_magento_api(cls, magento2url: str = None, magento_header: dict = None):
+    def set_magento_api(cls, url: str = None, header: dict = None):
         '''
         setting the magento store api connection details
-        :param magento2url: the url of the store
-        :param magento_header: dict with the relevant headers
+        :param url: the url of the store
+        :param header: dict with the relevant headers
         :return: None
         '''
-        if magento2url:
-            cls.magento_magento2url = magento2url
-        if magento_header:
-            cls.magento_headers = magento_header
+        if url:
+            cls.magento_magento2url = url
+        if header:
+            cls.magento_headers = header
 
     @classmethod
     def get_magento(cls, table: str = None, page: str = None, limit: str = None, add_total: str = None,
